-----------------------------------------------------------------------------------------------
-- Client Lua Script for LootRollEnhanced
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------

require "Window"
require "Sound"

local LootRollEnhanced = {}

-- Loot Roll Window
local currentRow = 1
local itemTable = {}
local windowLocation = nil

-- History Database
local itemHistoryTable = {}
local itemHistoryTablePointer = 1
local windowHistoryLocation = nil

local tSavedDataCopy

-- Settings
local bEnableBinds = false
local bWinningChatRollsOnly = false

local ktEvalColors = 
{
	[Item.CodeEnumItemQuality.Inferior] 		= ApolloColor.new("ItemQuality_Inferior"),
	[Item.CodeEnumItemQuality.Average] 			= ApolloColor.new("ItemQuality_Average"),
	[Item.CodeEnumItemQuality.Good] 			= ApolloColor.new("ItemQuality_Good"),
	[Item.CodeEnumItemQuality.Excellent] 		= ApolloColor.new("ItemQuality_Excellent"),
	[Item.CodeEnumItemQuality.Superb] 			= ApolloColor.new("ItemQuality_Superb"),
	[Item.CodeEnumItemQuality.Legendary] 		= ApolloColor.new("ItemQuality_Legendary"),
	[Item.CodeEnumItemQuality.Artifact]		 	= ApolloColor.new("ItemQuality_Artifact"),
}

function LootRollEnhanced:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self
    return o
end

function LootRollEnhanced:Init()
    Apollo.RegisterAddon(self)
end

function LootRollEnhanced:OnLoad()
	Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
	Apollo.RegisterEventHandler("AddonEvent_ToggleLootHistory", "OnToggleLootHistory", self)
	self.xmlDoc = XmlDoc.CreateFromFile("LootRollEnhanced.xml")
	self.xmlDoc:RegisterCallback("OnDocumentReady", self) 	
	Apollo.LoadSprites("LootRollEnhancedSprites.xml", "LootRollEnhancedSprites")
end

function LootRollEnhanced:OnSave(eType)
	if eType ~= GameLib.CodeEnumAddonSaveLevel.Character then
    	return nil
  	end

  	local tSavedData = {}

	tSavedData.lootWindowLocation = {}
	tSavedData.settings = {}
	
	if windowLocation ~= nil then
		tSavedData.lootWindowLocation = windowLocation:ToTable()
	end
	
	tSavedData.settings["EnableBinds"] = bEnableBinds
	tSavedData.settings["EnableWinOnlyChatMessage"] = bWinningChatRollsOnly
	
  	return tSavedData

end

function LootRollEnhanced:OnRestore(eType, tSavedData)
	tSavedDataCopy = tSavedData
	if tSavedData.lootWindowLocation ~= nil then
		if tSavedData.lootWindowLocation.fPoints ~= nil then
			if tSavedData.lootWindowLocation.nOffsets[1] == 0 and tSavedData.lootWindowLocation.nOffsets[3] == 0 then
				windowLocation = nil
			else 
				windowLocation = WindowLocation.new(tSavedData.lootWindowLocation)
			end
		end
	end

	if tSavedData.settings ~= nil then
		bEnableBinds = tSavedData.settings["EnableBinds"]
		bWinningChatRollsOnly = tSavedData.settings["EnableWinOnlyChatMessage"]
	end
			
end

function LootRollEnhanced:OnDocumentReady()
	if  self.xmlDoc == nil then
		return
	end
	
	Apollo.RegisterEventHandler("LootRollUpdate",		"OnGroupLoot", self)
    Apollo.RegisterTimerHandler("WinnerCheckTimer", 	"OnOneSecTimer", self)
    Apollo.RegisterEventHandler("LootRollWon", 			"OnLootRollWon", self)
    Apollo.RegisterEventHandler("LootRollAllPassed", 	"OnLootRollAllPassed", self)
	Apollo.RegisterEventHandler("LootRollSelected", 	"OnLootRollSelected", self)
	Apollo.RegisterEventHandler("LootRollPassed", 		"OnLootRollPassed", self)
	Apollo.RegisterEventHandler("LootRoll", 			"OnLootRoll", self)
	Apollo.RegisterEventHandler("ItemLink", 			"OnLootIconClick", self)
	Apollo.RegisterSlashCommand("lre", "OnToggleLootHistory", self)
	Apollo.RegisterSlashCommand("lres", "OnToggleSettings", self)
	Apollo.CreateTimer("WinnerCheckTimer", 1.0, false)
	Apollo.StopTimer("WinnerCheckTimer")
	self.wndMain = nil
	self.wndLootHistory = nil
	
	self.bTimerRunning = false
	self.tKnownLoot = nil
	self.tLootRolls = nil
	self.tMostRelevant = nil
	
	if GameLib.GetLootRolls() then
		self:OnGroupLoot()
	end

	-- Setup grid of players
	--for i=0,GroupLib.GetGroupMaxSize() do
	--	self.wndMain:FindChild("GroupMembersLootRoll"):AddRow("", nil, nil)
	--end

end

function LootRollEnhanced:OnInterfaceMenuListHasLoaded()
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "Loot Roll History", {"AddonEvent_ToggleLootHistory", "", "LootRollEnhancedSprites:MenuItemIcon"})
end

function LootRollEnhanced:Close()
	if self.wndMain then
		self.wndMain:Destroy()
	end
end

function LootRollEnhanced:OnCloseSettings()
	if self.wndSettings then
		self.wndSettings:Destroy()
	end	
end

-----------------------------------------------------------------------------------------------
-- Main Draw Methods
-----------------------------------------------------------------------------------------------
function LootRollEnhanced:OnGroupLoot()
	if not self.bTimerRunning then
		Apollo.StartTimer("WinnerCheckTimer")
		self.bTimerRunning = true
	end
end

function LootRollEnhanced:UpdateKnownLoot()
	self.tLootRolls = GameLib.GetLootRolls()
	if not self.tLootRolls or #self.tLootRolls <= 0 then
		self.tKnownLoot = nil
		self.tLootRolls = nil
		self.tMostRelevant = nil
		return
	end

	self.tKnownLoot = {}
	for idx, tCurrentElement in ipairs(self.tLootRolls) do
		self.tKnownLoot[tCurrentElement.nLootId] = tCurrentElement
	end
	
	if self.tMostRelevant then
		self.tMostRelevant = self.tKnownLoot[self.tMostRelevant.nLootId]
	end
	
	-- NOTE: self.tMostRelevant may have been set to nil above.
	if not self.tMostRelevant then
		for nLootId, tCurrentElement in pairs(self.tKnownLoot) do
			if not self.tMostRelevant or self.tMostRelevant.nTimeLeft > tCurrentElement.nTimeLeft then
				self.tMostRelevant = tCurrentElement
				--Print(math.floor(tCurrentElement.nTimeLeft / 1000))
			end
		end
	end
end

function LootRollEnhanced:OnOneSecTimer()
	self:UpdateKnownLoot()

	if not self.tLootRolls and self.wndMain and self.wndMain:IsShown() then
		self:Close()
	end

	if self.tMostRelevant then
		self:DrawLoot(self.tMostRelevant, #self.tLootRolls)
	end

	-- Art based on anchor
	if self.wndMain and self.wndMain:IsValid() then
		local nLeft, nTop, nRight, nBottom = self.wndMain:GetRect()
		if nLeft < 1 then
			self.wndMain:SetSprite("BK3:UI_BK3_Holo_Framing_2")
		else
			self.wndMain:SetSprite("BK3:UI_BK3_Holo_Framing_2")
		end
	end

	if self.tLootRolls and #self.tLootRolls > 0 then
		Apollo.StartTimer("WinnerCheckTimer")
	else
		self.bTimerRunning = false
	end
end

function LootRollEnhanced:DrawLoot(tCurrentElement, nItemsInQueue)
	if not self.wndMain or not self.wndMain:IsValid() or not self.wndMain:GetData() then
		self:Close()
		if bEnableBinds then
			self.wndMain = Apollo.LoadForm(self.xmlDoc, "LootRollEnhancedForm", nil, self)
		else
			self.wndMain = Apollo.LoadForm(self.xmlDoc, "LootRollEnhancedFormNoBinds", nil, self)
		end
		
		if windowLocation ~= nil then
			self.wndMain:MoveToLocation(windowLocation)
		else
			self.wndMain:MoveToLocation(self.wndMain:GetOriginalLocation())
		end
		Sound.Play(Sound.PlayUIWindowNeedVsGreedOpen)
	end
	self.wndMain:SetData(tCurrentElement.nLootId)

	local itemCurrent = tCurrentElement.itemDrop
	local itemModData = tCurrentElement.tModData
	local tGlyphData = tCurrentElement.tSigilData
	self.wndMain:FindChild("LootTitle"):SetText(itemCurrent:GetName())
	self.wndMain:FindChild("LootTitle"):SetTextColor(ktEvalColors[itemCurrent:GetItemQuality()])
	
	self.wndMain:FindChild("GiantItemIcon"):SetSprite(itemCurrent:GetIcon())
	self:HelperBuildItemTooltip(self.wndMain:FindChild("GiantItemIcon"), itemCurrent, itemModData, tGlyphData)

	if nItemsInQueue > 1 then -- Do items in queue
		self.wndMain:FindChild("ItemsInQueueIcon"):SetTooltip(string.format("<P Font=\"CRB_InterfaceSmall\">%s</P>", String_GetWeaselString(Apollo.GetString("NeedVsGreed_NumItems"), nItemsInQueue)))
		self.wndMain:FindChild("ItemsInQueueText"):SetText(nItemsInQueue)
	end
	self.wndMain:FindChild("ItemsInQueueIcon"):Show(nItemsInQueue > 1)
	self.wndMain:FindChild("NeedBtn"):Enable(GameLib.IsNeedRollAllowed(tCurrentElement.nLootId))
	
	-- TODO Timelimit
	local nTimeLeft = math.floor(tCurrentElement.nTimeLeft / 1000)
	self.wndMain:FindChild("TimeLeftText"):Show(true)
	
	local nTimeLeftSecs = nTimeLeft % 60
	local nTimeLeftMins = math.floor(nTimeLeft / 60)
	
	local strTimeLeft = tostring(nTimeLeftMins)
	if nTimeLeft < 0 then
		strTimeLeft = "0:00"
	elseif nTimeLeftSecs < 10 then
		strTimeLeft = strTimeLeft .. ":0" .. tostring(nTimeLeftSecs)
	else
		strTimeLeft = strTimeLeft .. ":" .. tostring(nTimeLeftSecs)
	end
	self.wndMain:FindChild("TimeLeftText"):SetText(strTimeLeft)
	self:UpdateUI()
end

function LootRollEnhanced:OnToggleLootHistory()
	if not self.wndLootHistory or not self.wndLootHistory:IsValid() then
		self.wndLootHistory = Apollo.LoadForm(self.xmlDoc, "LootRollEnhancedHistory", nil, self)
		Sound.Play(Sound.PlayUIWindowNeedVsGreedOpen)
	else
		self.wndLootHistory:Destroy()
		return
	end
	
	-- Draw Elements
	for i=1,itemHistoryTablePointer do
		self:DrawLootHistoryEntry(i)
	end
	
	-- Update Window
	self.wndLootHistory:FindChild("LootRollEnhancedHistoryEntryContainer"):RecalculateContentExtents()
end

function LootRollEnhanced:OnToggleSettings()
	if not self.wndSettings or not self.wndSettings:IsValid() then
		self.wndSettings = Apollo.LoadForm(self.xmlDoc, "LootRollEnhancedSettings", nil, self)
		self.wndSettings:FindChild("btnEnableKeybinds"):SetCheck(bEnableBinds)
		self.wndSettings:FindChild("btnEnableWinningRollsOnly"):SetCheck(bWinningChatRollsOnly)
		Sound.Play(Sound.PlayUIWindowNeedVsGreedOpen)
	else
		self.wndSettings:Destroy()
	end
end

function LootRollEnhanced:DrawLootHistoryEntry(entryNum)
	
	if itemHistoryTable[entryNum] == nil then 
		return
	end
	
	local wndLootHistoryEntry = self:FactoryProduce(self.wndLootHistory:FindChild("LootRollEnhancedHistoryEntryContainer"), "LootRollEnhancedHistoryEntry")
	wndLootHistoryEntry:SetData(itemHistoryTable[entryNum].item)
	local gridPlayerRolls = wndLootHistoryEntry:FindChild("PlayerRolls")
	local gridPlayerRollsCounter = 1
	local resultIcon = wndLootHistoryEntry:FindChild("LootResult")
	local itemIcon = wndLootHistoryEntry:FindChild("LootIcon")
	local wndLootHistoryHeight = wndLootHistoryEntry:GetHeight()
	local wndLootHistoryLocation = wndLootHistoryEntry:GetLocation():ToTable()
	
	-- Item Information
	if itemIcon then
		itemIcon:SetSprite(itemHistoryTable[entryNum].item:GetIcon())
		self:HelperBuildItemTooltip(itemIcon, itemHistoryTable[entryNum].item, itemHistoryTable[entryNum].item.tModData, itemHistoryTable[entryNum].item.tSigilData)
	end
	
	-- Personalized Result
	if resultIcon then
		resultIcon:SetSprite(itemHistoryTable[entryNum].resultIcon)
	end
	
	-- Player Rolls
	for name,type in pairs(itemHistoryTable[entryNum].players) do
		gridPlayerRolls:AddRow("", nil, nil)
		if name == itemHistoryTable[entryNum].winner then
			for i=1,3 do
				gridPlayerRolls:SelectCell(gridPlayerRollsCounter, i)
			end	
		end
		gridPlayerRolls:SetCellText(gridPlayerRollsCounter, 1, name)
		gridPlayerRolls:SetCellText(gridPlayerRollsCounter, 2, type)
		if itemHistoryTable[entryNum].rolls[name] == nil then
			itemHistoryTable[entryNum].rolls[name] = "--"
		end
		gridPlayerRolls:SetCellText(gridPlayerRollsCounter, 3, itemHistoryTable[entryNum].rolls[name])
		gridPlayerRollsCounter = gridPlayerRollsCounter + 1
	end
	
	wndLootHistoryLocation.nOffsets[2] = wndLootHistoryLocation.nOffsets[2] + (wndLootHistoryHeight * (itemHistoryTablePointer - entryNum - 1))
	wndLootHistoryLocation.nOffsets[4] = wndLootHistoryLocation.nOffsets[4] + (wndLootHistoryHeight * (itemHistoryTablePointer - entryNum - 1))

	local newWindowLocation = WindowLocation.new(wndLootHistoryLocation)
	wndLootHistoryEntry:MoveToLocation(newWindowLocation)
end

function LootRollEnhanced:FactoryProduce(wndParent, strFormName, tObject)
	local wndNew = wndParent:FindChildByUserData(tObject)
	if not wndNew then
		wndNew = Apollo.LoadForm(self.xmlDoc, strFormName, wndParent, self)
		wndNew:SetData(tObject)
	end
	return wndNew
end

-----------------------------------------------------------------------------------------------
-- Chat Message Events
-----------------------------------------------------------------------------------------------

function LootRollEnhanced:OnLootRollAllPassed(itemLooted)
	-- Can be fired without self.wndMain
	ChatSystemLib.PostOnChannel(ChatSystemLib.ChatChannel_Loot, String_GetWeaselString(Apollo.GetString("NeedVsGreed_EveryonePassed"), itemLooted:GetName()))
	-- Remove item from database
	itemTable[itemLooted:GetName()].players = nil
	itemTable[itemLooted:GetName()] = nil
end

function LootRollEnhanced:OnLootRollWon(itemLooted, strWinner, bNeed)
	-- Can be fired without self.wndMain
	local strNeedOrGreed = Apollo.GetString("NeedVsGreed_GreedRoll")
	if bNeed then
		strNeedOrGreed = Apollo.GetString("NeedVsGreed_NeedRoll")
	end
	
	-- Add item to history database
	itemHistoryTable[itemHistoryTablePointer] = {}
	itemHistoryTable[itemHistoryTablePointer].winner = strWinner
	itemHistoryTable[itemHistoryTablePointer].rolls = itemTable[itemLooted:GetName()].rolls
	itemHistoryTable[itemHistoryTablePointer].item = itemLooted
	itemHistoryTable[itemHistoryTablePointer].resultIcon = "CRB_CharacterCreateSprites:sprCharC_NameCheckNo"
	itemHistoryTable[itemHistoryTablePointer].players = itemTable[itemLooted:GetName()].players
	
	if GameLib.GetPlayerUnit():GetName() == strWinner then
		itemHistoryTable[itemHistoryTablePointer].resultIcon = "CRB_CharacterCreateSprites:sprCharC_NameCheckYes"	
	end
	
	-- Increment table pointer
	itemHistoryTablePointer = itemHistoryTablePointer + 1
	
	-- Remove item from active database
	itemTable[itemLooted:GetName()].players = nil
	itemTable[itemLooted:GetName()] = nil
	
	-- Example Message: Alvin used Greed Roll on Item Name for 45 (LootRoll).
	Event_FireGenericEvent("GenericEvent_LootChannelMessage", String_GetWeaselString(Apollo.GetString("NeedVsGreed_ItemWon"), strWinner, itemLooted:GetName(), strNeedOrGreed))
end

function LootRollEnhanced:OnLootRollSelected(nLootItem, strPlayer, bNeed)

	local strNeedOrGreed = Apollo.GetString("NeedVsGreed_GreedRoll")
	if bNeed then
		strNeedOrGreed = Apollo.GetString("NeedVsGreed_NeedRoll")
	end
	
	-- Example Message: strPlayer has selected to bNeed for nLootItem
	if not bWinningChatRollsOnly then
		Event_FireGenericEvent("GenericEvent_LootChannelMessage", String_GetWeaselString(Apollo.GetString("NeedVsGreed_LootRollSelected"), strPlayer, strNeedOrGreed, nLootItem:GetName()))
	end
	-- A player has rolled on an item, run LootRollEnhanced modifications 

	-- Update Database
	self:UpdateItemDB(nLootItem:GetName(), strPlayer, strNeedOrGreed)
	self:UpdateUI()
end

function LootRollEnhanced:UpdateItemDB(strItem, strPlayerName, strRoll)
	if itemTable[strItem] == nil then
		itemTable[strItem] = {}
		itemTable[strItem].players = {}
	end
	
	-- Add player and roll to specified item
  	itemTable[strItem].players[strPlayerName] = strRoll
	
end

function LootRollEnhanced:UpdateUI()
	currentRow = 1
	local strItem = ""

	if self.wndMain == nil then
		return
	end
			
	if self.wndMain:FindChild("LootTitle") ~= nil then
		strItem = self.wndMain:FindChild("LootTitle"):GetText()
	end
		
	if self.wndMain:FindChild("GroupMembersLootRoll") ~= nil then
		self.wndMain:FindChild("GroupMembersLootRoll"):DeleteAll()
	end
	
	for item,players in pairs(itemTable) do
		if item == strItem then
			for name,roll in pairs(players.players) do
				if self.wndMain:FindChild("GroupMembersLootRoll") then
					self.wndMain:FindChild("GroupMembersLootRoll"):AddRow("", nil, nil)
					self.wndMain:FindChild("GroupMembersLootRoll"):SetCellText(currentRow, 1, name)
					self.wndMain:FindChild("GroupMembersLootRoll"):SetCellText(currentRow, 2, roll)
					currentRow = currentRow + 1
				end
			end
		end
	end	
	
end

function LootRollEnhanced:OnLootRollPassed(nLootItem, strPlayer)

	-- Example Message: strPlayer passed on nLootItem
	if not bWinningChatRollsOnly then
		Event_FireGenericEvent("GenericEvent_LootChannelMessage", String_GetWeaselString(Apollo.GetString("NeedVsGreed_PlayerPassed"), strPlayer, nLootItem:GetName()))
	end
	
	-- LootRollEnhanced update for passing on an item
	self:UpdateItemDB(nLootItem:GetName(), strPlayer, "Pass")
end

function LootRollEnhanced:OnLootRoll(nLootItem, strPlayer, nRoll, bNeed)

	local strNeedOrGreed = Apollo.GetString("NeedVsGreed_GreedRoll")
	if bNeed then
		strNeedOrGreed = Apollo.GetString("NeedVsGreed_NeedRoll")
	end
	
	if itemTable[nLootItem:GetName()].rolls == nil then 
		itemTable[nLootItem:GetName()].rolls = {}
	end
	itemTable[nLootItem:GetName()].rolls[strPlayer] = nRoll
	
	-- Example String: strPlayer rolled nRoll for nLootItem (bNeed)
	if not bWinningChatRollsOnly then
		Event_FireGenericEvent("GenericEvent_LootChannelMessage", String_GetWeaselString(Apollo.GetString("NeedVsGreed_OnLootRoll"), strPlayer, nRoll, nLootItem:GetName(), strNeedOrGreed ))
	end
	-- Player rolled for item
	self:UpdateUI()
end

function LootRollEnhanced:OnSaveWindowPosition()
	windowLocation = self.wndMain:GetLocation()
end

-----------------------------------------------------------------------------------------------
-- Buttons
-----------------------------------------------------------------------------------------------

function LootRollEnhanced:OnNeedBtn(wndHandler, wndControl)
	GameLib.RollOnLoot(self.wndMain:GetData(), true)
	self:OnSaveWindowPosition()
	self:Close()
end

function LootRollEnhanced:OnGreedBtn(wndHandler, wndControl)
	GameLib.RollOnLoot(self.wndMain:GetData(), false)
	self:OnSaveWindowPosition()
	self:Close()
end

function LootRollEnhanced:OnPassBtn(wndHandler, wndControl)
	GameLib.PassOnLoot(self.wndMain:GetData())
	self:OnSaveWindowPosition()
	self:Close()
end

function LootRollEnhanced:HelperBuildItemTooltip(wndArg, itemCurr, itemModData, tGlyphData)
	wndArg:SetTooltipDoc(nil)
	wndArg:SetTooltipDocSecondary(nil)
	local itemEquipped = itemCurr:GetEquippedItemForItemType()
	Tooltip.GetItemTooltipForm(self, wndArg, itemCurr, {bPrimary = true, bSelling = false, itemCompare = itemEquipped, itemModData = itemModData, tGlyphData = tGlyphData})
	--if itemEquipped then -- OLD
	--	Tooltip.GetItemTooltipForm(self, wndArg, itemEquipped, {bPrimary = false, bSelling = false, itemCompare = itemCurr})
	--end
end

---------------------------------------------------------------------------------------------------
-- LootRollEnhancedSettings Functions
---------------------------------------------------------------------------------------------------

function LootRollEnhanced:OnEnableKeybinds( wndHandler, wndControl, eMouseButton )
	bEnableBinds = true
end

function LootRollEnhanced:OnDisableKeybinds( wndHandler, wndControl, eMouseButton )
	bEnableBinds = false
end

function LootRollEnhanced:OnEnableWinningRollsOnly( wndHandler, wndControl, eMouseButton )
	bWinningChatRollsOnly = true
end

function LootRollEnhanced:OnDisableWinningRollsOnly( wndHandler, wndControl, eMouseButton )
	bWinningChatRollsOnly = false
end

function LootRollEnhanced:OnShowTestWindow( wndHandler, wndControl, eMouseButton )
	if bEnableBinds then
		self.wndTestMain = Apollo.LoadForm(self.xmlDoc, "LootRollEnhancedForm", nil, self)
	else
		self.wndTestMain = Apollo.LoadForm(self.xmlDoc, "LootRollEnhancedFormNoBinds", nil, self)
	end

	self.wndTestMain:FindChild("GreedBtn"):Enable(false)
	self.wndTestMain:FindChild("NeedBtn"):Enable(false)
	self.wndTestMain:FindChild("PassBtn"):Enable(false)
	self.wndTestMain:FindChild("LootTitle"):SetText("Move Me!")
	--self.wndTestMain:Enable(false)
	
	if windowLocation ~= nil then
		self.wndTestMain:MoveToLocation(windowLocation)
	else
		self.wndTestMain:MoveToLocation(self.wndTestMain:GetOriginalLocation())
	end
	--	self.wndTestMain:Enable(false)
	Sound.Play(Sound.PlayUIWindowNeedVsGreedOpen)

end

function LootRollEnhanced:OnHideTestWindow( wndHandler, wndControl, eMouseButton )
	if self.wndTestMain then
		windowLocation = self.wndTestMain:GetLocation()
		self.wndTestMain:Destroy()
	end	
	Sound.Play(Sound.PlayUIWindowNeedVsGreedOpen)
end

---------------------------------------------------------------------------------------------------
-- LootRollEnhancedHistoryEntry Functions
---------------------------------------------------------------------------------------------------
function LootRollEnhanced:OnLinkLoot( wndHandler, wndControl, eMouseButton )
	local itemLinked = wndHandler:GetParent():GetData()
	
	if itemLinked == nil then
		return
	end

	tLink = {}
	tLink.uItem = itemLinked
	tLink.strText = String_GetWeaselString(Apollo.GetString("CRB_Brackets"), itemLinked:GetName())
	
	local chatAddon = nil
	
	if Apollo.GetAddon("ChatLog") ~= nil then
		chatAddon = Apollo.GetAddon("ChatLog")
	end 
	
	if Apollo.GetAddon("ImprovedChatLog") ~= nil then
		chatAddon = Apollo.GetAddon("ImprovedChatLog")
	end
	
	if chatAddon == nil then
		ChatSystemLib.PostOnChannel(2,"LootRollEnhanced: Incompatible Chat addon detected, please request an update to LootRollEnhanced for support!")
		return
	end
	
	local wndEdit = chatAddon:HelperGetCurrentEditbox()

	if wndEdit then
		chatAddon:HelperAppendLink(wndEdit, tLink)
	end
end

---------------------------------------------------------------------------------------------------
-- LootRollEnhancedForm Functions
---------------------------------------------------------------------------------------------------
local LootRollEnhancedInst = LootRollEnhanced:new()
LootRollEnhancedInst:Init()
